summaryrefslogtreecommitdiff
path: root/TAO/tao/ORB.h
diff options
context:
space:
mode:
authorirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-08-07 07:10:52 +0000
committerirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-08-07 07:10:52 +0000
commit647816a552cf70f1d553191dc15c5fece7814926 (patch)
tree180ab712fd188743f7d1e083f20bf2baf903d995 /TAO/tao/ORB.h
parentca2fae73b6a03275323004706b12aaa07931f37a (diff)
downloadATCD-647816a552cf70f1d553191dc15c5fece7814926.tar.gz
*** empty log message ***
Diffstat (limited to 'TAO/tao/ORB.h')
-rw-r--r--TAO/tao/ORB.h8
1 files changed, 7 insertions, 1 deletions
diff --git a/TAO/tao/ORB.h b/TAO/tao/ORB.h
index fe1f0bf878d..bee687d34b2 100644
--- a/TAO/tao/ORB.h
+++ b/TAO/tao/ORB.h
@@ -948,7 +948,13 @@ public:
virtual CORBA::ULong _decr_refcnt (void);
TAO_Leader_Follower_Info &leader_follower_info (void);
- // get access to the leader_follower_info
+ // Get access to the leader_follower_info
+
+ void should_shutdown (int value);
+ // Set the shutdown flag to <value>.
+
+ int should_shutdown (void);
+ // Get the shutdown flag value
protected:
// We must be created via the <ORB_init> call.